package com.ruoyi.framework.recovery.service.impl;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.FTPUtil;
import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.common.utils.uuid.UUID;
import com.ruoyi.framework.recovery.mapper.RecCommodityMapper;
import com.ruoyi.framework.recovery.service.ICommonService;
import lombok.extern.slf4j.Slf4j;
import net.coobird.thumbnailator.Thumbnails;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Objects;

@Service
@Slf4j
public class CommonServiceImpl implements ICommonService {
    @Autowired
    private FTPUtil ftpUtil;

    @Autowired
    private RecCommodityMapper commodityMapper;


    /**
     * 时间格式化
     */
    private final SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");

    @Override
    public AjaxResult uploadFile(MultipartFile file, String type) throws Exception {
        // 高清文件目录，以当天时间为目录
        String filePath = "recovery-hd/" + simpleDateFormat.format(new Date()) + "/";
        // 缩略图文件目录
        String fileThu = "";
        String suffix = Objects.requireNonNull(file.getOriginalFilename()).substring(file.getOriginalFilename().lastIndexOf("."));
        boolean isImg = false;
        if (suffix.equalsIgnoreCase("jpg") || suffix.equalsIgnoreCase("jpeg")
                || suffix.equalsIgnoreCase("png") || suffix.equalsIgnoreCase("gif")) {
            isImg = true;
            fileThu = "recovery-thum" + simpleDateFormat.format(new Date()) + "/";
        }
        // 生成新的文件名
        String newFileName = UUID.randomUUID() + suffix;
        File toFile = multipartFileToFile(file);
        // 上传至ftp服务器
        if (ftpUtil.uploadToFtp(filePath, newFileName, toFile)) {
            System.out.println("上传至ftp服务器！");
        } else {
            System.out.println("上传至ftp服务器失败!");
        }
        // 如果是图片，就上传缩略图
        if (isImg) {
            BufferedImage image = Thumbnails.of(file.getInputStream()).scale(0.8f).outputFormat(suffix).outputQuality(0.5).asBufferedImage();
            File newFile = new File(fileThu + newFileName);
            ImageIO.write(image, suffix.substring(1), newFile);
            ftpUtil.uploadToFtp(fileThu, newFileName, newFile);
        }
        updateDb(filePath + newFileName, fileThu + newFileName, type);

        // 上传并返回新文件名称
        String fileName = FileUploadUtils.upload(filePath, file);
        AjaxResult ajax = AjaxResult.success();
        ajax.put("url", filePath + newFileName);
        ajax.put("fileName", fileName);
        ajax.put("newFileName", FileUtils.getName(fileName));
        ajax.put("originalFilename", file.getOriginalFilename());
        return ajax;
    }


    private static File multipartFileToFile(MultipartFile file) throws Exception {

        File toFile = null;
        if (file.equals("") || file.getSize() <= 0) {
            file = null;
        } else {
            InputStream ins = null;
            ins = file.getInputStream();
            toFile = new File(file.getOriginalFilename());
            inputStreamToFile(ins, toFile);
            ins.close();
        }
        return toFile;
    }

    //获取流文件
    private static void inputStreamToFile(InputStream ins, File file) {
        try {
            OutputStream os = new FileOutputStream(file);
            int bytesRead = 0;
            byte[] buffer = new byte[8192];
            while ((bytesRead = ins.read(buffer, 0, 8192)) != -1) {
                os.write(buffer, 0, bytesRead);
            }
            os.close();
            ins.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 更新数据库内容
     *
     * @param hdUrl  高清图地址，若不是图片就文件地址
     * @param thuUrl 缩略图地址
     * @param type   更新到哪个表中
     */
    private void updateDb(String hdUrl, String thuUrl, String type) {
        switch (type) {
         case "commodity":
        }
    }
}
