package com.ruoyi.framework.recovery.service.impl;

import java.util.Date;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.framework.recovery.mapper.RecBrandMapper;
import com.ruoyi.framework.recovery.domain.RecBrand;
import com.ruoyi.framework.recovery.service.IRecBrandService;

/**
 * 回收品牌Service业务层处理
 *
 * @author jin
 * @date 2024-11-16
 */
@Service
public class RecBrandServiceImpl implements IRecBrandService
{
    @Autowired
    private RecBrandMapper recBrandMapper;

    /**
     * 查询回收品牌
     *
     * @param id 回收品牌主键
     * @return 回收品牌
     */
    @Override
    public RecBrand selectRecBrandById(Long id)
    {
        return recBrandMapper.selectRecBrandById(id);
    }

    /**
     * 查询回收品牌列表
     *
     * @param recBrand 回收品牌
     * @return 回收品牌
     */
    @Override
    public List<RecBrand> selectRecBrandList(RecBrand recBrand)
    {
        return recBrandMapper.selectRecBrandList(recBrand);
    }

    /**
     * 新增回收品牌
     *
     * @param recBrand 回收品牌
     * @return 结果
     */
    @Override
    public int insertRecBrand(RecBrand recBrand)
    {
        recBrand.setCreateDate(new Date());
        return recBrandMapper.insertRecBrand(recBrand);
    }

    /**
     * 修改回收品牌
     *
     * @param recBrand 回收品牌
     * @return 结果
     */
    @Override
    public int updateRecBrand(RecBrand recBrand)
    {
        return recBrandMapper.updateRecBrand(recBrand);
    }

    /**
     * 批量删除回收品牌
     *
     * @param ids 需要删除的回收品牌主键
     * @return 结果
     */
    @Override
    public int deleteRecBrandByIds(Long[] ids)
    {
        return recBrandMapper.deleteRecBrandByIds(ids);
    }

    /**
     * 删除回收品牌信息
     *
     * @param id 回收品牌主键
     * @return 结果
     */
    @Override
    public int deleteRecBrandById(Long id)
    {
        return recBrandMapper.deleteRecBrandById(id);
    }
}
